<?php
//$content_width is required even though this is a variable-width theme
if (!isset($content_width))
	$content_width = 400;

//makes replying look neat
if (!function_exists('dwcryosis_threaded_comments')):
function dwcryosis_threaded_comments() {
	if (get_option('thread_comments'))
		wp_enqueue_script('comment-reply');
}
add_action('wp_enqueue_scripts', 'dwcryosis_threaded_comments');
endif;

// displays "Comments are closed" instead of comment form when comments are closed.
if (!function_exists('dwcryosis_closed_comments')):
function dwcryosis_closed_comments() {
	echo '<p>', esc_html__('Comments are closed.', 'dw-cryosis'), '</p>';
}
add_action('comment_form_comments_closed', 'dwcryosis_closed_comments');
endif;

if (!function_exists('dwcryosis_setup')):
function dwcryosis_setup() { //adds theme support
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 190,
			'width'       => 190,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
	add_theme_support('title-tag');
	add_theme_support('automatic-feed-links');
	add_theme_support('customize-selective-refresh-widgets');
	add_theme_support('starter-content', array(
	'widgets' => array(
		'left-sidebar' => array(
			array(
				'text',
				array(
					'title' => __('First Sidebar', 'dw-cryosis'),
					'text' => _x('This is some text in the first sidebar.', 'Theme Starter Content', 'dw-cryosis')
				)
			),
			'meta'
		),
		'right-sidebar' => array(
			array(
				'text',
				array(
					'title' => __('Second Sidebar', 'dw-cryosis'),
					'text' => _x('This is some text in the second sidebar.', 'Theme Starter Content', 'dw-cryosis')
				)
			)
		)
	)
));
}
add_action('after_setup_theme', 'dwcryosis_setup');
endif;

if (!function_exists('dwcryosis_register_menu')):
function dwcryosis_register_menu() { //registers the menus, the header menus
	register_nav_menus(
		array(
	      'header_nav_menu' => __( 'Header Nav Menu', 'dw-cryosis' ),
		  'under_header_menu' => __( 'Under Header Menu', 'dw-cryosis' )
		)
    );
}
add_action( 'init', 'dwcryosis_register_menu' );
endif;

if (!function_exists('dwcryosis_stylesheet')):
function dwcryosis_stylesheet() { //enqueue stylesheets
	wp_enqueue_style('dw-cryosis-style', get_stylesheet_directory_uri().'/style.css');
	/* responsive design: */
	if (is_active_sidebar('left-sidebar')&&is_active_sidebar('right-sidebar')):
		wp_enqueue_style('dw-cryosis-mobile', get_stylesheet_directory_uri().'/mobile.css', array(), false, 'all and (max-width:899px)');
		//if there are two sidebars, use mobile stylesheet at width<900
	elseif (is_active_sidebar('left-sidebar')||is_active_sidebar('right-sidebar')):
		wp_enqueue_style('dw-cryosis-mobile', get_stylesheet_directory_uri().'/mobile.css', array(), false, 'all and (max-width:699px)');
		//if there is one sidebar, use mobile stylesheet at width<700
	else:
		wp_enqueue_style('dw-cryosis-mobile', get_stylesheet_directory_uri().'/mobile.css');
		//if there are no sidebars, use mobile stylesheet without width condition
	endif;
}

add_action('wp_enqueue_scripts', 'dwcryosis_stylesheet');
endif;

if (!function_exists('dwcryosis_sidebars')):
// register the sidebars
function dwcryosis_sidebars() {
	register_sidebar(array(
		'name' => __('Header Bar', 'dw-cryosis'),
		'id' => 'top-block'
	));
	register_sidebar(array(
		'name' => __('Left Sidebar', 'dw-cryosis'),
		'id' => 'left-sidebar'
	));
    register_sidebar(array(
		'name' => __('Left Sidebar 2', 'dw-cryosis'),
		'id' => 'left-sidebar2'
	));register_sidebar(array(
		'name' => __('Left Sidebar 3', 'dw-cryosis'),
		'id' => 'left-sidebar3'
	));register_sidebar(array(
		'name' => __('Left Sidebar 4', 'dw-cryosis'),
		'id' => 'left-sidebar4'
	));register_sidebar(array(
		'name' => __('Left Sidebar 5', 'dw-cryosis'),
		'id' => 'left-sidebar5'
	));
	register_sidebar(array(
		'name' => __('Right Sidebar', 'dw-cryosis'),
		'id' => 'right-sidebar'
	));
	register_sidebar(array(
		'name' => __('Right Sidebar 2', 'dw-cryosis'),
		'id' => 'right-sidebar2'
	));
	register_sidebar(array(
		'name' => __('Right Sidebar 3', 'dw-cryosis'),
		'id' => 'right-sidebar3'
	));
	register_sidebar(array(
		'name' => __('Right Sidebar 4', 'dw-cryosis'),
		'id' => 'right-sidebar4'
	));
	register_sidebar(array(
		'name' => __('Right Sidebar 5', 'dw-cryosis'),
		'id' => 'right-sidebar5'
	));
	register_sidebar(array(
		'name' => __('Center Block', 'dw-cryosis'),
		'id' => 'center-block'
	));
	register_sidebar(array(
		'name' => __('Center Block 2', 'dw-cryosis'),
		'id' => 'center-block2'
	));
	register_sidebar(array(
		'name' => __('Center Block 3', 'dw-cryosis'),
		'id' => 'center-block3'
	));
	register_sidebar(array(
		'name' => __('Center Block 4', 'dw-cryosis'),
		'id' => 'center-block4'
	));
	register_sidebar(array(
		'name' => __('Center Block 5', 'dw-cryosis'),
		'id' => 'center-block5'
	));
	register_sidebar(array(
		'name' => __('Footer Bar', 'dw-cryosis'),
		'id' => 'bottom-block'
	));
}

add_action('widgets_init', 'dwcryosis_sidebars');
endif;

if (!function_exists('dwcryosis_multiply_rgb')):
function dwcryosis_multiply_rgb($sixDHex, $multiplier) { /* function to multiply the red, green, blue values by the same amount, used in creation of stylesheets for custom colors */
	$rgbBits = hexdec(substr($sixDHex,1));
	$red = round($multiplier*(255 & ($rgbBits>>16)));
	$green = round($multiplier*(255 & ($rgbBits>>8)));
	$blue = round($multiplier*(255 & $rgbBits));
	return '#' . ($red<16?'0':'').dechex($red>255?255:$red) . ($green<16?'0':'').dechex($green>255?255:$green) . ($blue<16?'0':'').dechex($blue>255?255:$blue);
}
endif;

// display information about a post under the post title
if (!function_exists('dwcryosis_post_meta')):
function dwcryosis_post_meta() {
	echo '<div class="meta">';
	if (get_post_type() == 'page'):
		printf(
		/* translators: %s = author */
			esc_html__('Posted by %s', 'dw-cryosis'),
			get_the_author()
		);
	elseif (has_category()):
		printf(
		/* translators: %1$s = date, %2$s = categories, %3$s = author */
			esc_html__('Posted on %1$s in %2$s by %3$s', 'dw-cryosis'),
			get_the_date(),
			wp_kses_post(get_the_category_list(',')),
			get_the_author()
		);
	else:
		printf(
		/* translators: %1$s = date, %2$s = author */
			esc_html__('Posted on %1$s by %2$s', 'dw-cryosis'),
			get_the_date(),
			get_the_author()
		);
	endif;
	edit_post_link(_x('Edit','verb','dw-cryosis'),' | ');
	if (get_post_type() != 'page' && has_tag()):
		echo '<br />';
		the_tags();
	endif;
	echo '</div>';
}
endif;

// change the archive title to show the search query when showing the archive title on a search result page.
if (!function_exists('dwcryosis_search_title')):
function dwcryosis_search_title($title) {
	if (is_search())
	/* translators: %s = search query */
		$title = sprintf(__('Search: %s', 'dw-cryosis'),get_search_query());
	return $title;
}

add_filter('get_the_archive_title', 'dwcryosis_search_title');
endif;

function google_fonts() {
    wp_enqueue_style( 'google-fonts', 'https://fonts.googleapis.com/css2?family=Oswald:wght@200;300;400;500;600;700&display=swap', false );
}
add_action( 'wp_enqueue_scripts', 'google_fonts' );